services

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2024 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ConfigTranslator

type ConfigTranslator interface {
	TranslateConfig() map[keydefinitions.KeyDefinitionKey]config.Key
}

type EventChannels

type EventChannels interface {
	GetKeyEventChannel() chan x.GenericEvent
	GetStatusEventChannel() chan string
	GetReloadEventChannel() chan chan string
	Close()
}

type GohxkdConfigService added in v0.0.2

type GohxkdConfigService interface {
	VersionConfigService
	GetKeys() []config.Key
	GetScreen() string
	GetConfig() config.Config
}

type KeyRunner

type KeyRunner interface {
	SetKeymap(map[keydefinitions.KeyDefinitionKey]config.Key)
	Find(keydefinitions.KeyDefinitionKey) (config.Key, bool)
	ClearBindings()
}

type KeyTranslator

type KeyTranslator interface {
	TranslateKey(config.Key) (keydefinitions.KeyDefinitionKey, error)
}

type Keybinder

type Keybinder interface {
	BindKeys(map[keydefinitions.KeyDefinitionKey]config.Key)
	UnbindKeys(map[keydefinitions.KeyDefinitionKey]config.Key)
}

type KeysymTranslator

type KeysymTranslator interface {
	GetKeycodes(x.Keysym) []x.Keycode
}

type Logger added in v0.0.2

type Logger interface {

	// Implement to log an error and then call panic
	Panic(...any)

	// Implement to print all messages sent to it
	Println(...any)

	// Implement to print all messages sent to it
	Print(...any)

	// Implement to print all messages with an Emergancy category
	PrintEmergancy(...any)

	// Implement to print all message with an Alert category
	PrintAlert(...any)

	// Implement to print all messages with a Critical category
	PrintCritical(...any)

	// Implement to print all messages with an Error category
	PrintError(...any)

	// Implement to print all messages with a Warning category
	PrintWarning(...any)

	// Implement to print all messages with a Notice category
	PrintNotice(...any)

	// Implement to print all messages with an Info category
	PrintInfo(...any)

	// Implement to print all messages with a Debug category
	PrintDebug(...any)
}

Logger is the basis of any loggers that are used in goxhkd and related programs

type ReloadService

type ReloadService interface {
	ReloadConfig() string
}

type VersionConfigService added in v0.0.2

type VersionConfigService interface {
	GetVersionFlag() bool
}

type VersionService added in v0.0.2

type VersionService interface {
	ShowVersion()
}

type XConnection

type XConnection interface {
	Connect() error
	ConnectToDisplay(string) error

	MakeAndAddEventChan(int) (chan x.GenericEvent, error)
	GetRootWindow() (x.Window, error)
	SetErrorCallback(func(*x.Error)) error

	GetXConnection() *x.Conn
	Flush()
	GrabKey(uint16, x.Keycode)
	UngrabKey(uint16, x.Keycode)
	GrabKeyboard()
	UngrabKeyboard()
	Close()
}

Directories

Path Synopsis
config

Jump to